@@ -8,7 +8,8 @@
 #ifndef BFS_ALLOC_H
 #define BFS_ALLOC_H
 
-#include "prelude.h"
+#include "bfs.h"
+
 #include <errno.h>
 #include <stddef.h>
 #include <stdlib.h>
