@@ -18,9 +18,10 @@
  *   various helper functions to take fewer parameters.
  */
 
-#include "prelude.h"
 #include "bftw.h"
+
 #include "alloc.h"
+#include "bfs.h"
 #include "bfstd.h"
 #include "diag.h"
 #include "dir.h"
@@ -30,6 +31,7 @@
 #include "mtab.h"
 #include "stat.h"
 #include "trie.h"
+
 #include <errno.h>
 #include <fcntl.h>
 #include <stdlib.h>
@@ -1281,8 +1283,8 @@ static int bftw_pin_parent(struct bftw_state *state, struct bftw_file *file) {
 
 	int fd = parent->fd;
 	if (fd < 0) {
-		bfs_static_assert((int)AT_FDCWD != -1);
-		return -1;
+		// Don't confuse failures with AT_FDCWD
+		return (int)AT_FDCWD == -1 ? -2 : -1;
 	}
 
 	bftw_cache_pin(&state->cache, parent);
