@@ -8,19 +8,10 @@
 #ifndef BFS_DIAG_H
 #define BFS_DIAG_H
 
-#include "prelude.h"
+#include "bfs.h"
 #include "bfstd.h"
-#include <stdarg.h>
 
-/**
- * static_assert() with an optional second argument.
- */
-#if __STDC_VERSION__ >= C23
-#  define bfs_static_assert static_assert
-#else
-#  define bfs_static_assert(...) bfs_static_assert_(__VA_ARGS__, #__VA_ARGS__, )
-#  define bfs_static_assert_(expr, msg, ...) _Static_assert(expr, msg)
-#endif
+#include <stdarg.h>
 
 /**
  * A source code location.
