@@ -8,7 +8,8 @@
 #ifndef BFS_DIR_H
 #define BFS_DIR_H
 
-#include "prelude.h"
+#include "bfs.h"
+
 #include <sys/types.h>
 
 /**
