@@ -5,10 +5,11 @@
  * Implementation of all the primary expressions.
  */
 
-#include "prelude.h"
 #include "eval.h"
+
 #include "atomic.h"
 #include "bar.h"
+#include "bfs.h"
 #include "bfstd.h"
 #include "bftw.h"
 #include "color.h"
@@ -27,11 +28,13 @@
 #include "stat.h"
 #include "trie.h"
 #include "xregex.h"
+
 #include <errno.h>
 #include <fcntl.h>
 #include <fnmatch.h>
 #include <grp.h>
 #include <pwd.h>
+#include <signal.h>
 #include <stdarg.h>
 #include <stdint.h>
 #include <stdio.h>
