@@ -25,8 +25,10 @@
  * effects are reachable at all, skipping the traversal if not.
  */
 
-#include "prelude.h"
 #include "opt.h"
+
+#include "bfs.h"
+#include "bfstd.h"
 #include "bftw.h"
 #include "bit.h"
 #include "color.h"
@@ -38,6 +40,8 @@
 #include "expr.h"
 #include "list.h"
 #include "pwcache.h"
+#include "xspawn.h"
+
 #include <errno.h>
 #include <limits.h>
 #include <stdarg.h>
@@ -1399,12 +1403,11 @@ static struct bfs_expr *sink_not_andor(struct bfs_opt *opt, struct bfs_expr *exp
 
 /** Sink a negation into a comma expression. */
 static struct bfs_expr *sink_not_comma(struct bfs_opt *opt, struct bfs_expr *expr) {
-	bfs_assert(expr->eval_fn == eval_comma);
-
-	opt_enter(opt, "%pe\n", expr);
-
 	char **argv = expr->argv;
 	expr = only_child(expr);
+	opt_enter(opt, "%pe\n", expr);
+
+	bfs_assert(expr->eval_fn == eval_comma);
 
 	struct bfs_exprs children;
 	foster_children(expr, &children);
@@ -1816,7 +1819,7 @@ static struct bfs_expr *opt_ignore(struct bfs_opt *opt, struct bfs_expr *expr, b
 	if (delete) {
 		opt_delete(opt, "%pe [ignored result]\n", expr);
 	} else {
-		opt_debug(opt, "ignored result");
+		opt_debug(opt, "ignored result\n");
 	}
 
 	if (expr->kind != BFS_TEST) {
