@@ -17,14 +17,17 @@
  * drop to zero.  Once it does, the old pointer can be safely freed.
  */
 
-#include "prelude.h"
 #include "sighook.h"
+
 #include "alloc.h"
 #include "atomic.h"
+#include "bfs.h"
 #include "bfstd.h"
 #include "diag.h"
 #include "thread.h"
+
 #include <errno.h>
+#include <pthread.h>
 #include <signal.h>
 #include <stdlib.h>
 #include <unistd.h>
