@@ -81,16 +81,18 @@
  * and insert intermediate singleton "jump" nodes when necessary.
  */
 
-#include "prelude.h"
 #include "trie.h"
+
 #include "alloc.h"
+#include "bfs.h"
 #include "bit.h"
 #include "diag.h"
 #include "list.h"
+
 #include <stdint.h>
 #include <string.h>
 
-bfs_static_assert(CHAR_WIDTH == 8);
+static_assert(CHAR_WIDTH == 8, "This trie implementation assumes 8-bit bytes.");
 
 #if __i386__ || __x86_64__
 #  define _trie_clones _target_clones("popcnt", "default")
