@@ -1,12 +1,14 @@
 // Copyright © Tavian Barnes <tavianator@tavianator.com>
 // SPDX-License-Identifier: 0BSD
 
-#include "prelude.h"
 #include "xspawn.h"
+
 #include "alloc.h"
+#include "bfs.h"
 #include "bfstd.h"
 #include "diag.h"
 #include "list.h"
+
 #include <errno.h>
 #include <fcntl.h>
 #include <signal.h>
@@ -16,7 +18,7 @@
 #include <sys/types.h>
 #include <unistd.h>
 
-#if BFS_USE_PATHS_H
+#if __has_include(<paths.h>)
 #  include <paths.h>
 #endif
 
