@@ -1,11 +1,13 @@
 // Copyright © Tavian Barnes <tavianator@tavianator.com>
 // SPDX-License-Identifier: 0BSD
 
-#include "prelude.h"
 #include "tests.h"
-#include "sighook.h"
+
 #include "atomic.h"
 #include "thread.h"
+#include "sighook.h"
+
+#include <stddef.h>
 #include <errno.h>
 #include <pthread.h>
 #include <signal.h>
