@@ -1,10 +1,12 @@
 // Copyright © Tavian Barnes <tavianator@tavianator.com>
 // SPDX-License-Identifier: 0BSD
 
-#include "prelude.h"
 #include "tests.h"
-#include "trie.h"
+
+#include "bfs.h"
 #include "diag.h"
+#include "trie.h"
+
 #include <stdlib.h>
 #include <string.h>
 
